Not necessarily complete list of things to do
=============================================

(mainly so I don't forget, and because issues are kinda heavy, at
least at this point)

Documentation:

- topic on searching

- topic on DB admin, especially packing

- topic on deletion

- topic on transaction management

- topic expanding the tasks example to make it more realistic

Medium priorities:

- Custom transformations

- Async support

- handle transformed data in the jsonifier
